@@ -25,13 +25,10 @@
 #include <X11/keysym.h>
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-program.h>
 
 #include <gkbd-keyboard-config.h>
 #include <gkbd-config-private.h>
 
-#include <gkbd-config-registry-client.h>
-
 /**
  * GkbdKeyboardConfig
  */
@@ -51,23 +48,6 @@ const gchar *GKBD_KEYBOARD_CONFIG_ACTIVE[] = {
 	GKBD_KEYBOARD_CONFIG_KEY_OPTIONS
 };
 
-#define GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX GKBD_CONFIG_KEY_PREFIX "/kbd.sysbackup"
-
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_DIR[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX;
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_MODEL[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/model";
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_LAYOUTS[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/layouts";
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_OPTIONS[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/options";
-
-const gchar *GKBD_KEYBOARD_CONFIG_SYSBACKUP[] = {
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_MODEL,
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_LAYOUTS,
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_OPTIONS
-};
-
 /**
  * static common functions
  */
@@ -110,26 +90,32 @@ gkbd_keyboard_config_get_lv_descriptions (XklConfigRegistry *
 					  gchar ** variant_short_descr,
 					  gchar ** variant_descr)
 {
-	static XklConfigItem litem;
-	static XklConfigItem vitem;
+	/* TODO make it not static */
+	static XklConfigItem *litem = NULL;
+	static XklConfigItem *vitem = NULL;
+
+	if (litem == NULL)
+		litem = xkl_config_item_new ();
+	if (vitem == NULL)
+		vitem = xkl_config_item_new ();
 
 	layout_name = g_strdup (layout_name);
 
-	g_snprintf (litem.name, sizeof litem.name, "%s", layout_name);
-	if (xkl_config_registry_find_layout (config_registry, &litem)) {
-		*layout_short_descr = litem.short_description;
-		*layout_descr = litem.description;
+	g_snprintf (litem->name, sizeof litem->name, "%s", layout_name);
+	if (xkl_config_registry_find_layout (config_registry, litem)) {
+		*layout_short_descr = litem->short_description;
+		*layout_descr = litem->description;
 	} else
 		*layout_short_descr = *layout_descr = NULL;
 
 	if (variant_name != NULL) {
 		variant_name = g_strdup (variant_name);
-		g_snprintf (vitem.name, sizeof vitem.name, "%s",
+		g_snprintf (vitem->name, sizeof vitem->name, "%s",
 			    variant_name);
 		if (xkl_config_registry_find_variant
-		    (config_registry, layout_name, &vitem)) {
-			*variant_short_descr = vitem.short_description;
-			*variant_descr = vitem.description;
+		    (config_registry, layout_name, vitem)) {
+			*variant_short_descr = vitem->short_description;
+			*variant_descr = vitem->description;
 		} else
 			*variant_short_descr = *variant_descr = NULL;
 
@@ -526,14 +512,6 @@ gkbd_keyboard_config_load_from_gconf (GkbdKeyboardConfig * kbd_config,
 	}
 }
 
-void
-gkbd_keyboard_config_load_from_gconf_backup (GkbdKeyboardConfig *
-					     kbd_config)
-{
-	gkbd_keyboard_config_load_params (kbd_config,
-					  GKBD_KEYBOARD_CONFIG_SYSBACKUP);
-}
-
 void
 gkbd_keyboard_config_load_from_x_current (GkbdKeyboardConfig * kbd_config,
 					  XklConfigRec * data)
@@ -609,28 +587,6 @@ gkbd_keyboard_config_save_to_gconf (GkbdKeyboardConfig * kbd_config)
 	gconf_change_set_unref (cs);
 }
 
-void
-gkbd_keyboard_config_save_to_gconf_backup (GkbdKeyboardConfig * kbd_config)
-{
-	GConfChangeSet *cs;
-	GError *gerror = NULL;
-
-	cs = gconf_change_set_new ();
-
-	gkbd_keyboard_config_save_params (kbd_config, cs,
-					  GKBD_KEYBOARD_CONFIG_SYSBACKUP);
-
-	gconf_client_commit_change_set (kbd_config->conf_client, cs, TRUE,
-					&gerror);
-	if (gerror != NULL) {
-		g_warning ("Error saving backup configuration: %s\n",
-			   gerror->message);
-		g_error_free (gerror);
-		gerror = NULL;
-	}
-	gconf_change_set_unref (cs);
-}
-
 void
 gkbd_keyboard_config_model_set (GkbdKeyboardConfig * kbd_config,
 				const gchar * model_name)
@@ -788,8 +744,8 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 					 (const gchar *) iter->data);
 		}
 
-		/* TRANS: The count is related to the number of options. The %s format specifier should not be modified,
-		 * left "as is". */
+		/* Translators: The count is related to the number of options. The %s
+		 * format specifier should not be modified, left "as is". */
 		layouts =
 		    g_strdup_printf (ngettext
 				     ("layout \"%s\"", "layouts \"%s\"",
@@ -807,8 +763,8 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 					 (const gchar *) iter->data);
 		}
 
-		/* TRANS: The count is related to the number of options. The %s format specifier should not be modified,
-		 * left "as is". */
+		/* Translators: The count is related to the number of options. The %s
+		 * format specifier should not be modified, left "as is". */
 		options =
 		    g_strdup_printf (ngettext
 				     ("option \"%s\"", "options \"%s\"",
